==> glame_0.6.2.orig.tar.gz: glame-0.6.2/src/plugins/builtins.c <==
#include "glplugin.h"
int drop_register(plugin_t *p);
int one2n_register(plugin_t *p);
int buffer_register(plugin_t *p);
int mix_register(plugin_t *p);
int render_register(plugin_t *p);
int volume_adjust_register(plugin_t *p);
int delay_register(plugin_t *p);
int extend_register(plugin_t *p);
int repeat_register(plugin_t *p);
int pan2_register(plugin_t *p);
int swapfile_in_register(plugin_t *p);
int swapfile_out_register(plugin_t *p);
int audio_out_register(plugin_t *p);
int audio_in_register(plugin_t *p);
int read_file_register(plugin_t *p);
int file_io_register(plugin_t *p);
int write_file_register(plugin_t *p);
int mul_register(plugin_t *p);
int add_register(plugin_t *p);
int invert_register(plugin_t *p);
int sine_register(plugin_t *p);
int const_register(plugin_t *p);
int rect_register(plugin_t *p);
int ramp_register(plugin_t *p);
int saw_register(plugin_t *p);
int noise_register(plugin_t *p);
int pulse_register(plugin_t *p);
int wave_register(plugin_t *p);
int ssp_streamer_register(plugin_t *p);
int maxrms_register(plugin_t *p);
int echo_register(plugin_t *p);
int noisegate_register(plugin_t *p);
int pan_register(plugin_t *p);
int pipe_in_register(plugin_t *p);
int pipe_out_register(plugin_t *p);
int highpass_register(plugin_t *p);
int lowpass_register(plugin_t *p);
int bandpass_register(plugin_t *p);
int bandpass_a_register(plugin_t *p);
int flanger_register(plugin_t *p);
int distortion_register(plugin_t *p);
int fadein_register(plugin_t *p);
int fadeout_register(plugin_t *p);
void register_builtins() {
	plugin_t *p;
	if ((p = plugin_add("drop"))) if (drop_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("one2n"))) if (one2n_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("buffer"))) if (buffer_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("mix"))) if (mix_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("render"))) if (render_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("volume_adjust"))) if (volume_adjust_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("delay"))) if (delay_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("extend"))) if (extend_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("repeat"))) if (repeat_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pan2"))) if (pan2_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("swapfile_in"))) if (swapfile_in_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("swapfile_out"))) if (swapfile_out_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("audio_out"))) if (audio_out_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("audio_in"))) if (audio_in_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("read_file"))) if (read_file_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("file_io"))) if (file_io_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("write_file"))) if (write_file_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("mul"))) if (mul_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("add"))) if (add_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("invert"))) if (invert_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("sine"))) if (sine_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("const"))) if (const_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("rect"))) if (rect_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("ramp"))) if (ramp_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("saw"))) if (saw_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("noise"))) if (noise_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pulse"))) if (pulse_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("wave"))) if (wave_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("ssp_streamer"))) if (ssp_streamer_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("maxrms"))) if (maxrms_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("echo"))) if (echo_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("noisegate"))) if (noisegate_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pan"))) if (pan_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pipe_in"))) if (pipe_in_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pipe_out"))) if (pipe_out_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("highpass"))) if (highpass_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("lowpass"))) if (lowpass_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("bandpass"))) if (bandpass_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("bandpass_a"))) if (bandpass_a_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("flanger"))) if (flanger_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("distortion"))) if (distortion_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("fadein"))) if (fadein_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("fadeout"))) if (fadeout_register(p) == -1) _plugin_delete(p);
}

==> glame_2.0.1.orig.tar.gz: glame-2.0.1/src/plugins/builtins.c <==
#include "glplugin.h"
int drop_register(plugin_t *p);
int one2n_register(plugin_t *p);
int buffer_register(plugin_t *p);
int mix_register(plugin_t *p);
int render_register(plugin_t *p);
int volume_adjust_register(plugin_t *p);
int delay_register(plugin_t *p);
int extend_register(plugin_t *p);
int repeat_register(plugin_t *p);
int pan2_register(plugin_t *p);
int clip_register(plugin_t *p);
int swapfile_in_register(plugin_t *p);
int swapfile_out_register(plugin_t *p);
int audio_out_register(plugin_t *p);
int audio_in_register(plugin_t *p);
int read_file_register(plugin_t *p);
int write_file_register(plugin_t *p);
int mul_register(plugin_t *p);
int add_register(plugin_t *p);
int invert_register(plugin_t *p);
int sine_register(plugin_t *p);
int const_register(plugin_t *p);
int rect_register(plugin_t *p);
int ramp_register(plugin_t *p);
int saw_register(plugin_t *p);
int noise_register(plugin_t *p);
int pulse_register(plugin_t *p);
int wave_register(plugin_t *p);
int ssp_streamer_register(plugin_t *p);
int maxrms_register(plugin_t *p);
int echo_register(plugin_t *p);
int noisegate_register(plugin_t *p);
int pan_register(plugin_t *p);
int pipe_in_register(plugin_t *p);
int pipe_out_register(plugin_t *p);
int highpass_register(plugin_t *p);
int lowpass_register(plugin_t *p);
int bandpass_register(plugin_t *p);
int bandpass_a_register(plugin_t *p);
int flanger_register(plugin_t *p);
int distortion_register(plugin_t *p);
int fadein_register(plugin_t *p);
int fadeout_register(plugin_t *p);
int stretch_register(plugin_t *p);
void register_builtins() {
	plugin_t *p;
	if ((p = plugin_add("drop"))) if (drop_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("one2n"))) if (one2n_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("buffer"))) if (buffer_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("mix"))) if (mix_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("render"))) if (render_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("volume_adjust"))) if (volume_adjust_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("delay"))) if (delay_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("extend"))) if (extend_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("repeat"))) if (repeat_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pan2"))) if (pan2_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("clip"))) if (clip_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("swapfile_in"))) if (swapfile_in_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("swapfile_out"))) if (swapfile_out_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("audio_out"))) if (audio_out_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("audio_in"))) if (audio_in_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("read_file"))) if (read_file_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("write_file"))) if (write_file_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("mul"))) if (mul_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("add"))) if (add_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("invert"))) if (invert_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("sine"))) if (sine_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("const"))) if (const_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("rect"))) if (rect_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("ramp"))) if (ramp_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("saw"))) if (saw_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("noise"))) if (noise_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pulse"))) if (pulse_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("wave"))) if (wave_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("ssp_streamer"))) if (ssp_streamer_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("maxrms"))) if (maxrms_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("echo"))) if (echo_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("noisegate"))) if (noisegate_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pan"))) if (pan_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pipe_in"))) if (pipe_in_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("pipe_out"))) if (pipe_out_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("highpass"))) if (highpass_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("lowpass"))) if (lowpass_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("bandpass"))) if (bandpass_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("bandpass_a"))) if (bandpass_a_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("flanger"))) if (flanger_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("distortion"))) if (distortion_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("fadein"))) if (fadein_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("fadeout"))) if (fadeout_register(p) == -1) _plugin_delete(p);
	if ((p = plugin_add("stretch"))) if (stretch_register(p) == -1) _plugin_delete(p);
}
